gransy
    * ``auth_username`` Specify username for authentication

    * ``auth_password`` Specify password for authentication


.. note::
   
   DNS manipulation provider for Gransy sites subreg.cz, regtons.com and regnames.eu.

